@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'swift::storage::account' do
   let :pre_condition do
      "class { 'swift': swift_hash_path_suffix => 'foo' }
-     class { 'swift::storage': storage_local_net_ip => '10.0.0.1' }"
+     class { 'swift::storage::all': storage_local_net_ip => '10.0.0.1' }"
   end
 
   let :params do
@@ -69,9 +69,10 @@ describe 'swift::storage::account' do
 
   context 'on Debian platforms' do
     let :facts do
-      {:operatingsystem => 'Ubuntu',
-       :osfamily        => 'Debian' }
-
+      OSDefaults.get_facts({
+       :operatingsystem => 'Ubuntu',
+       :osfamily        => 'Debian',
+      })
     end
 
     let :platform_params do
@@ -109,8 +110,10 @@ describe 'swift::storage::account' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily        => 'RedHat',
-        :operatingsystem => 'RedHat' }
+      OSDefaults.get_facts({
+        :osfamily        => 'RedHat',
+        :operatingsystem => 'RedHat',
+      })
     end
 
     let :platform_params do
